@@ -130,7 +130,7 @@ class AsyncPymarketcap(ClientSession):
 
     @property
     def total_currencies(self):
-        """Get all exchange raw names provided by coinmarketcap."""
+        """Get all currency names provided by coinmarketcap."""
         try:
             return self._total_currencies
         except AttributeError:
@@ -184,7 +184,11 @@ class AsyncPymarketcap(ClientSession):
     async def _async_multiget(self, itr, build_url_callback,
                               num_of_consumers=None, desc=""):
         queue, dlq, responses = Queue(maxsize=self.queue_size), Queue(), []
-        num_of_consumers = num_of_consumers or min(self.connector_limit, self.try_get_itr_len(itr))
+        try:
+            itr_len = len(itr)
+        except TypeError:
+            itr_len = 1000000
+        num_of_consumers = num_of_consumers or min(self.connector_limit, itr_len)
         consumers = [ensure_future(
             self._consumer(main_queue=queue, dlq=dlq, responses=responses)) for _ in
                      range(num_of_consumers or self.connector_limit)]
@@ -200,12 +204,6 @@ class AsyncPymarketcap(ClientSession):
             consumer.cancel()
         return responses
 
-    def try_get_itr_len(self, itr):
-        try:
-            return len(itr)
-        except TypeError:
-            return 1000000
-
     async def _producer(self, items,
                         build_url_callback,
                         queue, desc=""):
@@ -265,6 +263,7 @@ class AsyncPymarketcap(ClientSession):
                  + "for %d currencies from coinmarketcap" % len(currencies)
         )
         for url, raw_res in res:
+            self.logger.debug("Processing data from %s" % url)
             response = processer.currency(raw_res[20000:], convert)
             response["slug"] = url.split("/")[-1]
             for symbol, slug in self.correspondences.items():
@@ -310,6 +309,7 @@ class AsyncPymarketcap(ClientSession):
                  + "for %d currencies from coinmarketcap" % len(currencies)
         )
         for url, raw_res in res:
+            self.logger.debug("Processing data from %s" % url)
             response = {"markets": processer.markets(raw_res[20000:], convert),
                         "slug": url.split("/")[-1]}
             for symbol, slug in self.correspondences.items():
@@ -383,6 +383,7 @@ class AsyncPymarketcap(ClientSession):
                  + "for %d currencies from coinmarketcap" % len(currencies)
         )
         for url, raw_res in res:
+            self.logger.debug("Processing data from %s" % url)
             response = {"history": processer.historical(raw_res[50000:],
                                                         start, end, revert),
                         "slug": url.split("/historical-data")[0].split("/")[-1]}
@@ -439,6 +440,7 @@ class AsyncPymarketcap(ClientSession):
                  + "for %d exchanges from coinmarketcap" % len(exchanges)
         )
         for url, raw_res in res:
+            self.logger.debug("Processing data from %s" % url)
             response = processer.exchange(raw_res, convert)
             response["slug"] = url.split("/")[-1]
             yield response
@@ -497,6 +499,7 @@ class AsyncPymarketcap(ClientSession):
                  + "for %d currencies from coinmarketcap" % len(currencies)
         )
         for url, raw_res in res:
+            self.logger.debug("Processing data from %s" % url)
             try:
                 raw_res = loads(raw_res)
             except JSONDecodeError:  # Ignore 404 responses
